# The PILOT Drive Backend

Built in Python 3.11, the backend utilizes a WebSocket to communicate with the UI along with multiple multiprocessing processes running simultaneously to allow for asynchrony.
